@@ -306,10 +306,16 @@ func hydrate(ns string, oo []runtime.Object, rr render.Rows, re Renderer) error
 	return nil
 }
 
+// Generic represents a generic resource.
 type Generic interface {
-	SetTable(*metav1beta1.Table)
-	Header(string) render.Header
-	Render(interface{}, string, *render.Row) error
+	// SetTable sets up the resource tabular definition.
+	SetTable(ns string, table *metav1beta1.Table)
+
+	// Header returns a resource header.
+	Header(ns string) render.Header
+
+	// Render renders the resource.
+	Render(o interface{}, ns string, row *render.Row) error
 }
 
 func genericHydrate(ns string, table *metav1beta1.Table, rr render.Rows, re Renderer) error {
@@ -317,7 +323,7 @@ func genericHydrate(ns string, table *metav1beta1.Table, rr render.Rows, re Rend
 	if !ok {
 		return fmt.Errorf("expecting generic renderer but got %T", re)
 	}
-	gr.SetTable(table)
+	gr.SetTable(ns, table)
 	for i, row := range table.Rows {
 		if err := gr.Render(row, ns, &rr[i]); err != nil {
 			return err
