@@ -21,8 +21,8 @@ import (
 	"github.com/derailed/k9s/internal/ui"
 	"github.com/derailed/k9s/internal/ui/dialog"
 	"github.com/derailed/k9s/internal/watch"
+	"github.com/derailed/tcell/v2"
 	"github.com/derailed/tview"
-	"github.com/gdamore/tcell/v2"
 	"github.com/rs/zerolog/log"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
@@ -595,10 +595,9 @@ func (a *App) dirCmd(path string) error {
 			path = dir
 		}
 	}
-	a.Content.Stack.Clear()
 	a.cmdHistory.Push("dir " + path)
 
-	return a.inject(NewDir(path))
+	return a.inject(NewDir(path), true)
 }
 
 func (a *App) helpCmd(evt *tcell.EventKey) *tcell.EventKey {
@@ -613,7 +612,7 @@ func (a *App) helpCmd(evt *tcell.EventKey) *tcell.EventKey {
 		return nil
 	}
 
-	if err := a.inject(NewHelp(a)); err != nil {
+	if err := a.inject(NewHelp(a), false); err != nil {
 		a.Flash().Err(err)
 	}
 
@@ -630,7 +629,7 @@ func (a *App) aliasCmd(evt *tcell.EventKey) *tcell.EventKey {
 		return nil
 	}
 
-	if err := a.inject(NewAlias(client.NewGVR("aliases"))); err != nil {
+	if err := a.inject(NewAlias(client.NewGVR("aliases")), false); err != nil {
 		a.Flash().Err(err)
 	}
 
@@ -644,12 +643,17 @@ func (a *App) gotoResource(cmd, path string, clearStack bool) {
 	}
 }
 
-func (a *App) inject(c model.Component) error {
+func (a *App) inject(c model.Component, clearStack bool) error {
 	ctx := context.WithValue(context.Background(), internal.KeyApp, a)
 	if err := c.Init(ctx); err != nil {
 		log.Error().Err(err).Msgf("component init failed for %q", c.Name())
-		dialog.ShowError(a.Styles.Dialog(), a.Content.Pages, err.Error())
+		//dialog.ShowError(a.Styles.Dialog(), a.Content.Pages, err.Error())
+		return err
 	}
+	if clearStack {
+		a.Content.Stack.Clear()
+	}
+
 	a.Content.Push(c)
 
 	return nil
